# kattest
Script for testing your code with the sample data files provided by Kattis.

## Requirements
* Python 3.6 or above.

## Supported languages
* C
* C++
* Java
* Python 3

## How to install
On Ubuntu / Mint, install <i>kattest</i> with the following commands:
```
sudo apt update
sudo apt install python3-dev python3-pip python3-setuptools
sudo pip3 install kattest
```
On other systems, install <i>kattest</i> by using `pip`:
```
pip install kattest
```

## How to run
### Kattis
Run the following command from the same directory as your solution:
```
kattest [Problem ID].[extension]
Example: kattest exponial.cpp
```

### Code Forces
Run the following command from the same directory as your solution:
```
kattest CF [Problem ID].[extension]
Example: kattest CF 1328A.cpp
```

Enjoy!